/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mime4j.message;

/**
 * A <tt>Disposable</tt> is an object that should be disposed of explicitly
 * when it is no longer needed.
 * 
 * The dispose method is invoked to release resources that the object is
 * holding (such as open files). 
 */
public interface Disposable {
    /**
     * Free any resources this object is holding and prepares this object
     * for garbage collection. Once an object has been disposed of it can no
     * longer be used.
     */
    void dispose();
}
